from __future__ import absolute_import, division, print_function, unicode_literals

from django.conf import settings
from django.core.checks import Warning


def check_switch_defaults(app_configs, **kwargs):
    errors = []
    if hasattr(settings, 'GARGOYLE_SWITCH_DEFAULTS'):
        for key, switch_defaults in settings.GARGOYLE_SWITCH_DEFAULTS.items():
            if 'is_active' in switch_defaults and 'initial_status' in switch_defaults:
                errors.append(Warning(
                    '"is_active" will take precedence over "initial_status" in GARGOYLE_SWITCH_DEFAULTS.',
                    hint="settings.GARGOYLE_SWITCH_DEFAULTS['{}']".format(key),
                    id='gargoyle.001',
                ))
    return errors



from __future__ import absolute_import, division, print_function, unicode_literals

from django.apps import AppConfig
from django.core import checks

from gargoyle.checks import check_switch_defaults


class GargoyleAppConfig(AppConfig):
    name = 'gargoyle'
    verbose_name = 'Gargoyle'

    def ready(self):
        checks.register(check_switch_defaults)
        self.module.autodiscover()



from __future__ import absolute_import, division, print_function, unicode_literals

# Django 2.0

try:
    from django.urls import reverse  # noqa pragma: no cover
except ImportError:
    from django.core.urlresolvers import reverse  # noqa pragma: no cover



#!/usr/bin/env python
from __future__ import absolute_import, division, print_function

import os
import re

from setuptools import find_packages, setup


def get_version(filename):
    with open(filename, 'r') as fp:
        contents = fp.read()
    return re.search(r"__version__ = ['\"]([^'\"]+)['\"]", contents).group(1)


version = get_version(os.path.join('gargoyle', '__init__.py'))

with open('README.rst', 'r') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst', 'r') as history_file:
    history = history_file.read().replace('.. :changelog:', '')

setup(
    name='gargoyle-yplan',
    version=version,
    author='DISQUS',
    author_email='opensource@disqus.com',
    maintainer='Adam Johnson',
    maintainer_email='me@adamj.eu',
    url='https://github.com/adamchainz/gargoyle',
    description=(
        'Gargoyle is a platform built on top of Django which allows you to switch functionality of your application '
        'on and off based on conditions.'
    ),
    long_description=readme + '\n\n' + history,
    packages=find_packages(exclude=['tests', 'tests.*']),
    zip_safe=False,
    install_requires=[
        'Django>=1.11',
        'django-modeldict-yplan>=2.0.0',
        'nexus-yplan>=2.1.0',
        'django-jsonfield>=1.2.0',
    ],
    python_requires='>=3.4',
    license='Apache License 2.0',
    include_package_data=True,
    classifiers=[
        'Development Status :: 7 - Inactive',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Framework :: Django :: 2.0',
        'Framework :: Django :: 2.1',
        'Framework :: Django :: 2.2',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python',
        'Topic :: Software Development',
    ],
)
